window.Gleam.initSearch([{"doc":"glistix_birl","title":"glistix_birl","content":"![birl](https://raw.githubusercontent.com/glistix/birl/main/banner.png)\n\n[![Package Version](https://img.shields.io/hexpm/v/glistix_birl)](https://hex.pm/packages/glistix_birl)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glistix_birl/)\n[![Nix-compatible](https://img.shields.io/badge/target-nix-5277C3)](https://github.com/glistix/glistix)\n\n# glistix-birl\n\n**Mirrors:** [**GitHub**](https://github.com/Glistix/birl) | [**Codeberg**](https://codeberg.org/Glistix/birl)\n\n[Glistix](https://github.com/glistix/glistix) fork of [`birl`](https://github.com/massivefermion/birl), a Date/Time handling library for Gleam.\n\nAdds **support for the Nix target.** For that, implements the algorithms at [http://howardhinnant.github.io/date_algorithms.html](http://howardhinnant.github.io/date_algorithms.html).\n\nIts documentation can be found at &lt;https://hexdocs.pm/glistix_birl&gt;.\n\n&gt; [!WARNING]\n&gt;\n&gt; **Disclaimer:** This is an **unofficial** fork of `birl` and we are not affiliated with its authors. If you are not using Glistix with the Nix target, consider using the original [`birl`](https://hex.pm/packages/birl) package directly instead.\n\n## &lt;img width=32 src=&quot;https://raw.githubusercontent.com/massivefermion/birl/main/icon.png&quot;&gt; Notes\n\nDue to purity constraints, **the Nix target cannot access the local timezone of the system.**\nHowever, **it can access the current time, but only outside pure-eval mode** (otherwise it&#39;s\nassumed to be Jan 1, 1970, or 0 in Unix time). Do note, however, that accessing the current time\n**can only be done once per evaluation** (later calls to `now()` always return the same result).\n\nOtherwise, the functions and algorithms should work just fine (just try not to depend on the\ncurrent time).\n\n## &lt;img width=32 src=&quot;https://raw.githubusercontent.com/massivefermion/birl/main/icon.png&quot;&gt; Quick start\n\n```sh\nnix develop   # Optional: Enter a shell with glistix\nglistix run   # Run the project\nglistix test  # Run the tests\n```\n\n## &lt;img width=32 src=&quot;https://raw.githubusercontent.com/massivefermion/birl/main/icon.png&quot;&gt; Installation\n\n## Installation\n\n_For the most recent instructions, please see [the Glistix handbook](https://glistix.github.io/book/recipes/overriding-packages.html)._\n\nYou can use this fork by running `glistix add birl` followed by adding the line below to your Glistix project&#39;s `gleam.toml` file (as of Glistix v0.7.0):\n\n```toml\n[glistix.preview.patch]\n# ... Existing patches ...\n# Add this line:\nbirl = { name = &quot;glistix_birl&quot;, version = &quot;&gt;= 1.0.0 and &lt; 2.0.0&quot; }\n```\n\nThis ensures transitive dependencies on `birl` will also use the patch.\n\nKeep in mind that patches only have an effect on end users&#39; projects - they are ignored when publishing a package to Hex, so end users are responsible for any patches their dependencies may need.\n\nIf your project or package is only meant for the Nix target, you can also use this fork in `[dependencies]` directly through `glistix add glistix_birl` in order to not rely on patching. However, the patch above is still going to be necessary for end users to fix other dependencies which depend on `birl`.\n\n## &lt;img width=32 src=&quot;https://raw.githubusercontent.com/massivefermion/birl/main/icon.png&quot;&gt; Usage\n\n```gleam\nimport birl\nimport birl/duration\n\npub fn main() {\n    let now = birl.now()\n    let two_weeks_later = birl.add(now, duration.weeks(2))\n    birl.to_iso8601(two_weeks_later)\n}\n```\n","url":"index.html"},{"doc":"birl/duration","title":"Duration","content":"pub type Duration {\n  Duration(Int)\n}\n\nDuration(Int)\n\n\nSynonyms:\nbirl/duration.Duration\nbirl/duration Duration","url":"birl/duration.html#Duration"},{"doc":"birl/duration","title":"Unit","content":"pub type Unit {\n  MicroSecond\n  MilliSecond\n  Second\n  Minute\n  Hour\n  Day\n  Week\n  Month\n  Year\n}\n\nMicroSecond\n\n\nMilliSecond\n\n\nSecond\n\n\nMinute\n\n\nHour\n\n\nDay\n\n\nWeek\n\n\nMonth\n\n\nYear\n\n\nSynonyms:\nbirl/duration.Unit\nbirl/duration Unit","url":"birl/duration.html#Unit"},{"doc":"birl/duration","title":"accurate_decompose","content":"pub fn accurate_decompose(\n  duration: Duration,\n) -&gt; List(#(Int, Unit))\n use this if you need very long durations where small inaccuracies could lead to large errors\nSynonyms:\nbirl/duration.accurate_decompose\nbirl/duration accurate_decompose","url":"birl/duration.html#accurate_decompose"},{"doc":"birl/duration","title":"accurate_new","content":"pub fn accurate_new(values: List(#(Int, Unit))) -&gt; Duration\n use this if you need very long durations where small inaccuracies could lead to large errors\nSynonyms:\nbirl/duration.accurate_new\nbirl/duration accurate_new","url":"birl/duration.html#accurate_new"},{"doc":"birl/duration","title":"add","content":"pub fn add(a: Duration, b: Duration) -&gt; Duration\n\nSynonyms:\nbirl/duration.add\nbirl/duration add","url":"birl/duration.html#add"},{"doc":"birl/duration","title":"blur","content":"pub fn blur(duration: Duration) -&gt; #(Int, Unit)\n approximates the duration by a value in a single unit\nSynonyms:\nbirl/duration.blur\nbirl/duration blur","url":"birl/duration.html#blur"},{"doc":"birl/duration","title":"blur_to","content":"pub fn blur_to(duration: Duration, unit: Unit) -&gt; Int\n approximates the duration by only the given unit\n \n if the duration is not an integer multiple of the unit,\n the remainder will be disgarded if it&#39;s less than two thirds of the unit,\n otherwise a single unit will be added to the multiplier.\n \n   - `blur_to(days(16), Month)` -&gt;  `0`\n   - `blur_to(days(20), Month)` -&gt;  `1`\nSynonyms:\nbirl/duration.blur_to\nbirl/duration blur_to","url":"birl/duration.html#blur_to"},{"doc":"birl/duration","title":"compare","content":"pub fn compare(a: Duration, b: Duration) -&gt; Order\n\nSynonyms:\nbirl/duration.compare\nbirl/duration compare","url":"birl/duration.html#compare"},{"doc":"birl/duration","title":"days","content":"pub fn days(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.days\nbirl/duration days","url":"birl/duration.html#days"},{"doc":"birl/duration","title":"decompose","content":"pub fn decompose(duration: Duration) -&gt; List(#(Int, Unit))\n use this if you need short durations where a year just means 365 days and a month just means 30 days\nSynonyms:\nbirl/duration.decompose\nbirl/duration decompose","url":"birl/duration.html#decompose"},{"doc":"birl/duration","title":"hours","content":"pub fn hours(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.hours\nbirl/duration hours","url":"birl/duration.html#hours"},{"doc":"birl/duration","title":"micro_seconds","content":"pub fn micro_seconds(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.micro_seconds\nbirl/duration micro_seconds","url":"birl/duration.html#micro_seconds"},{"doc":"birl/duration","title":"milli_seconds","content":"pub fn milli_seconds(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.milli_seconds\nbirl/duration milli_seconds","url":"birl/duration.html#milli_seconds"},{"doc":"birl/duration","title":"minutes","content":"pub fn minutes(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.minutes\nbirl/duration minutes","url":"birl/duration.html#minutes"},{"doc":"birl/duration","title":"months","content":"pub fn months(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.months\nbirl/duration months","url":"birl/duration.html#months"},{"doc":"birl/duration","title":"new","content":"pub fn new(values: List(#(Int, Unit))) -&gt; Duration\n use this if you need short durations where a year just means 365 days and a month just means 30 days\nSynonyms:\nbirl/duration.new\nbirl/duration new","url":"birl/duration.html#new"},{"doc":"birl/duration","title":"parse","content":"pub fn parse(expression: String) -&gt; Result(Duration, Nil)\n you can use this function to create a new duration using expressions like:\n\n     &quot;accurate: 1 Year - 2days + 152M -1h + 25 years + 25secs&quot;\n\n where the units are:\n\n     Year:         y, Y, YEAR, years, Years, ...\n\n     Month:        mon, Month, mONths, ...\n\n     Week:         w, W, Week, weeks, ...\n\n     Day:          d, D, day, Days, ...\n\n     Hour:         h, H, Hour, Hours, ...\n\n     Minute:       m, M, Min, minute, Minutes, ...\n\n     Second:       s, S, sec, Secs, second, Seconds, ...\n\n     MilliSecond:  ms, Msec, mSecs, milliSecond, MilliSecond, ...\n\n numbers with no unit are considered as microseconds.\n specifying `accurate:` is equivalent to using `accurate_new`.\nSynonyms:\nbirl/duration.parse\nbirl/duration parse","url":"birl/duration.html#parse"},{"doc":"birl/duration","title":"scale_down","content":"pub fn scale_down(value: Duration, factor: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.scale_down\nbirl/duration scale_down","url":"birl/duration.html#scale_down"},{"doc":"birl/duration","title":"scale_up","content":"pub fn scale_up(value: Duration, factor: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.scale_up\nbirl/duration scale_up","url":"birl/duration.html#scale_up"},{"doc":"birl/duration","title":"seconds","content":"pub fn seconds(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.seconds\nbirl/duration seconds","url":"birl/duration.html#seconds"},{"doc":"birl/duration","title":"subtract","content":"pub fn subtract(a: Duration, b: Duration) -&gt; Duration\n\nSynonyms:\nbirl/duration.subtract\nbirl/duration subtract","url":"birl/duration.html#subtract"},{"doc":"birl/duration","title":"weeks","content":"pub fn weeks(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.weeks\nbirl/duration weeks","url":"birl/duration.html#weeks"},{"doc":"birl/duration","title":"years","content":"pub fn years(value: Int) -&gt; Duration\n\nSynonyms:\nbirl/duration.years\nbirl/duration years","url":"birl/duration.html#years"},{"doc":"birl/duration","title":"birl/duration","content":"","url":"birl/duration.html"},{"doc":"birl","title":"Day","content":"pub type Day {\n  Day(year: Int, month: Int, date: Int)\n}\n\nDay(year: Int, month: Int, date: Int)\n\n\nSynonyms:\nbirl.Day\nbirl Day","url":"birl.html#Day"},{"doc":"birl","title":"Month","content":"pub type Month {\n  Jan\n  Feb\n  Mar\n  Apr\n  May\n  Jun\n  Jul\n  Aug\n  Sep\n  Oct\n  Nov\n  Dec\n}\n\nJan\n\n\nFeb\n\n\nMar\n\n\nApr\n\n\nMay\n\n\nJun\n\n\nJul\n\n\nAug\n\n\nSep\n\n\nOct\n\n\nNov\n\n\nDec\n\n\nSynonyms:\nbirl.Month\nbirl Month","url":"birl.html#Month"},{"doc":"birl","title":"Time","content":"pub opaque type Time\n\n\nSynonyms:\nbirl.Time\nbirl Time","url":"birl.html#Time"},{"doc":"birl","title":"TimeOfDay","content":"pub type TimeOfDay {\n  TimeOfDay(\n    hour: Int,\n    minute: Int,\n    second: Int,\n    milli_second: Int,\n  )\n}\n\nTimeOfDay(hour: Int, minute: Int, second: Int, milli_second: Int)\n\n\nSynonyms:\nbirl.TimeOfDay\nbirl TimeOfDay","url":"birl.html#TimeOfDay"},{"doc":"birl","title":"Weekday","content":"pub type Weekday {\n  Mon\n  Tue\n  Wed\n  Thu\n  Fri\n  Sat\n  Sun\n}\n\nMon\n\n\nTue\n\n\nWed\n\n\nThu\n\n\nFri\n\n\nSat\n\n\nSun\n\n\nSynonyms:\nbirl.Weekday\nbirl Weekday","url":"birl.html#Weekday"},{"doc":"birl","title":"unix_epoch","content":"pub const unix_epoch: Time\n starting point of unix timestamps\nSynonyms:\nbirl.unix_epoch\nbirl unix_epoch","url":"birl.html#unix_epoch"},{"doc":"birl","title":"add","content":"pub fn add(value: Time, duration: Duration) -&gt; Time\n\nSynonyms:\nbirl.add\nbirl add","url":"birl.html#add"},{"doc":"birl","title":"compare","content":"pub fn compare(a: Time, b: Time) -&gt; Order\n\nSynonyms:\nbirl.compare\nbirl compare","url":"birl.html#compare"},{"doc":"birl","title":"difference","content":"pub fn difference(a: Time, b: Time) -&gt; Duration\n\nSynonyms:\nbirl.difference\nbirl difference","url":"birl.html#difference"},{"doc":"birl","title":"from_erlang_local_datetime","content":"pub fn from_erlang_local_datetime(\n  erlang_datetime: #(#(Int, Int, Int), #(Int, Int, Int)),\n) -&gt; Time\n calculates the DateTime value from the erlang datetime using the local offset of the system\nSynonyms:\nbirl.from_erlang_local_datetime\nbirl from_erlang_local_datetime","url":"birl.html#from_erlang_local_datetime"},{"doc":"birl","title":"from_erlang_universal_datetime","content":"pub fn from_erlang_universal_datetime(\n  erlang_datetime: #(#(Int, Int, Int), #(Int, Int, Int)),\n) -&gt; Time\n calculates the DateTime value from the erlang datetime in UTC\nSynonyms:\nbirl.from_erlang_universal_datetime\nbirl from_erlang_universal_datetime","url":"birl.html#from_erlang_universal_datetime"},{"doc":"birl","title":"from_http","content":"pub fn from_http(value: String) -&gt; Result(Time, Nil)\n see [here](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Date)\n\n also supports other similar formats:\n\n   - `Tue, 01-Nov-2016 08:49:37 GMT`\n\n   - `Tue, 01 Nov 2016 08:49:37 +0630`\n\n   - `Tue, 01-November-2016 08:49:37 Z`\n\n   - `Tuesday, 01-Nov-2016 08:49:37 +330`\n\n   - `Tuesday, 01 November 2016 08:49:37 +06:30`\nSynonyms:\nbirl.from_http\nbirl from_http","url":"birl.html#from_http"},{"doc":"birl","title":"from_naive","content":"pub fn from_naive(value: String) -&gt; Result(Time, Nil)\n accepts fromats similar to the ones listed for `parse` except that there shoundn&#39;t be any offset information\nSynonyms:\nbirl.from_naive\nbirl from_naive","url":"birl.html#from_naive"},{"doc":"birl","title":"from_unix","content":"pub fn from_unix(value: Int) -&gt; Time\n unix timestamps are the number of seconds that have elapsed since 00:00:00 UTC on January 1st, 1970\nSynonyms:\nbirl.from_unix\nbirl from_unix","url":"birl.html#from_unix"},{"doc":"birl","title":"get_day","content":"pub fn get_day(value: Time) -&gt; Day\n\nSynonyms:\nbirl.get_day\nbirl get_day","url":"birl.html#get_day"},{"doc":"birl","title":"get_offset","content":"pub fn get_offset(value: Time) -&gt; String\n\nSynonyms:\nbirl.get_offset\nbirl get_offset","url":"birl.html#get_offset"},{"doc":"birl","title":"get_time_of_day","content":"pub fn get_time_of_day(value: Time) -&gt; TimeOfDay\n\nSynonyms:\nbirl.get_time_of_day\nbirl get_time_of_day","url":"birl.html#get_time_of_day"},{"doc":"birl","title":"get_timezone","content":"pub fn get_timezone(value: Time) -&gt; Option(String)\n\nSynonyms:\nbirl.get_timezone\nbirl get_timezone","url":"birl.html#get_timezone"},{"doc":"birl","title":"legible_difference","content":"pub fn legible_difference(a: Time, b: Time) -&gt; String\n\nSynonyms:\nbirl.legible_difference\nbirl legible_difference","url":"birl.html#legible_difference"},{"doc":"birl","title":"monotonic_now","content":"pub fn monotonic_now() -&gt; Int\n\nSynonyms:\nbirl.monotonic_now\nbirl monotonic_now","url":"birl.html#monotonic_now"},{"doc":"birl","title":"month","content":"pub fn month(value: Time) -&gt; Month\n\nSynonyms:\nbirl.month\nbirl month","url":"birl.html#month"},{"doc":"birl","title":"now","content":"pub fn now() -&gt; Time\n use this to get the current time in the local timezone offset\nSynonyms:\nbirl.now\nbirl now","url":"birl.html#now"},{"doc":"birl","title":"now_with_offset","content":"pub fn now_with_offset(offset: String) -&gt; Result(Time, Nil)\n use this to get the current time with a given offset.\n\n some examples of acceptable offsets:\n\n `&quot;+330&quot;, &quot;03:30&quot;, &quot;-8:00&quot;,&quot;-7&quot;, &quot;-0400&quot;, &quot;03&quot;`\nSynonyms:\nbirl.now_with_offset\nbirl now_with_offset","url":"birl.html#now_with_offset"},{"doc":"birl","title":"now_with_timezone","content":"pub fn now_with_timezone(timezone: String) -&gt; Result(Time, Nil)\n\nSynonyms:\nbirl.now_with_timezone\nbirl now_with_timezone","url":"birl.html#now_with_timezone"},{"doc":"birl","title":"parse","content":"pub fn parse(value: String) -&gt; Result(Time, Nil)\n if you need to parse an `ISO8601` string, this is probably what you&#39;re looking for.\n\n given the huge surface area that `ISO8601` covers, it does not make sense for `birl`\n to support all of it in one function, so this function parses only strings for which both\n day and time of day can be extracted or deduced. Some acceptable examples are given below:\n\n   - `2019t14-4` -&gt; `2019-01-01T14:00:00.000-04:00`\n\n   - `2019-03-26t14:00.9z` -&gt; `2019-03-26T14:00:00.900Z`\n\n   - `2019-03-26+330` -&gt; `2019-03-26T00:00:00.000+03:30`\n\n   - `20190326t1400-4` -&gt; `2019-03-26T14:00:00.000-04:00`\n\n   - `19051222T16:38-3` -&gt; `1905-12-22T16:38:00.000-03:00`\n\n   - `2019-03-26 14:30:00.9Z` -&gt; `2019-03-26T14:30:00.900Z`\n\n   - `2019-03-26T14:00:00.9Z` -&gt; `2019-03-26T14:00:00.900Z`\n\n   - `1905-12-22 16:38:23-3` -&gt; `1905-12-22T16:38:23.000-03:00`\n\n   - `2019-03-26T14:00:00,4999Z` -&gt; `2019-03-26T14:00:00.499Z`\n\n   - `1905-12-22T163823+0330` -&gt; `1905-12-22T16:38:23.000+03:30`\n\n   - `1905-12-22T16:38:23.000+03:30` -&gt; `1905-12-22T16:38:23.000+03:30`\nSynonyms:\nbirl.parse\nbirl parse","url":"birl.html#parse"},{"doc":"birl","title":"parse_naive_time_of_day","content":"pub fn parse_naive_time_of_day(\n  value: String,\n) -&gt; Result(#(TimeOfDay, String), Nil)\n accepts fromats similar to the ones listed for `parse_time_of_day` except that there shoundn&#39;t be any offset information\nSynonyms:\nbirl.parse_naive_time_of_day\nbirl parse_naive_time_of_day","url":"birl.html#parse_naive_time_of_day"},{"doc":"birl","title":"parse_relative","content":"pub fn parse_relative(\n  origin: Time,\n  legible_difference: String,\n) -&gt; Result(Time, Nil)\n you could say this is the opposite of `legible_difference`\n\n \n &gt; parse_relative(birl.now(), &quot;8 minutes ago&quot;)\n \nSynonyms:\nbirl.parse_relative\nbirl parse_relative","url":"birl.html#parse_relative"},{"doc":"birl","title":"parse_time_of_day","content":"pub fn parse_time_of_day(\n  value: String,\n) -&gt; Result(#(TimeOfDay, String), Nil)\n this function parses `ISO8601` strings in which no date is specified, which\n means such inputs don&#39;t actually represent a particular moment in time. That&#39;s why\n the result of this function is an instance of `TimeOfDay` along with the offset specificed\n in the string. Some acceptable examples are given below:\n\n   - `t25z` -&gt; `#(TimeOfDay(2, 5, 0, 0), &quot;Z&quot;)`\n\n   - `14-4` -&gt; `#(TimeOfDay(14, 0, 0, 0), &quot;-04:00&quot;)`\n\n   - `T145+4` -&gt; `#(TimeOfDay(14, 5, 0, 0), &quot;+04:00&quot;)`\n\n   - `16:38-3` -&gt; `#(TimeOfDay(16, 38, 0, 0), &quot;-03:00&quot;)`\n\n   - `t14:65.9z` -&gt; `#(TimeOfDay(14, 6, 5, 900), &quot;-04:00&quot;)`\n\n   - `163823+0330` -&gt; `#(TimeOfDay(16, 38, 23, 0), &quot;+03:30&quot;)`\n\n   - `T16:38:23.050+03:30` -&gt; `#(TimeOfDay(16, 38, 23, 50), &quot;+03:30&quot;)`\nSynonyms:\nbirl.parse_time_of_day\nbirl parse_time_of_day","url":"birl.html#parse_time_of_day"},{"doc":"birl","title":"range","content":"pub fn range(\n  from a: Time,\n  to b: Option(Time),\n  step s: Duration,\n) -&gt; Iterator(Time)\n can be used to create a time range starting from time `a` with step `s`\n\n if `b` is `option.None` the range will be infinite\nSynonyms:\nbirl.range\nbirl range","url":"birl.html#range"},{"doc":"birl","title":"set_day","content":"pub fn set_day(value: Time, day: Day) -&gt; Time\n\nSynonyms:\nbirl.set_day\nbirl set_day","url":"birl.html#set_day"},{"doc":"birl","title":"set_offset","content":"pub fn set_offset(\n  value: Time,\n  new_offset: String,\n) -&gt; Result(Time, Nil)\n use this to change the offset of a given time value.\n\n some examples of acceptable offsets:\n\n `&quot;+330&quot;, &quot;03:30&quot;, &quot;-8:00&quot;,&quot;-7&quot;, &quot;-0400&quot;, &quot;03&quot;, &quot;Z&quot;`\nSynonyms:\nbirl.set_offset\nbirl set_offset","url":"birl.html#set_offset"},{"doc":"birl","title":"set_time_of_day","content":"pub fn set_time_of_day(value: Time, time: TimeOfDay) -&gt; Time\n\nSynonyms:\nbirl.set_time_of_day\nbirl set_time_of_day","url":"birl.html#set_time_of_day"},{"doc":"birl","title":"set_timezone","content":"pub fn set_timezone(\n  value: Time,\n  new_timezone: String,\n) -&gt; Result(Time, Nil)\n\nSynonyms:\nbirl.set_timezone\nbirl set_timezone","url":"birl.html#set_timezone"},{"doc":"birl","title":"short_string_month","content":"pub fn short_string_month(value: Time) -&gt; String\n\nSynonyms:\nbirl.short_string_month\nbirl short_string_month","url":"birl.html#short_string_month"},{"doc":"birl","title":"short_string_weekday","content":"pub fn short_string_weekday(value: Time) -&gt; String\n\nSynonyms:\nbirl.short_string_weekday\nbirl short_string_weekday","url":"birl.html#short_string_weekday"},{"doc":"birl","title":"string_month","content":"pub fn string_month(value: Time) -&gt; String\n\nSynonyms:\nbirl.string_month\nbirl string_month","url":"birl.html#string_month"},{"doc":"birl","title":"string_weekday","content":"pub fn string_weekday(value: Time) -&gt; String\n\nSynonyms:\nbirl.string_weekday\nbirl string_weekday","url":"birl.html#string_weekday"},{"doc":"birl","title":"subtract","content":"pub fn subtract(value: Time, duration: Duration) -&gt; Time\n\nSynonyms:\nbirl.subtract\nbirl subtract","url":"birl.html#subtract"},{"doc":"birl","title":"to_date_string","content":"pub fn to_date_string(value: Time) -&gt; String\n returns a string which is the date part of an ISO8601 string along with the offset\nSynonyms:\nbirl.to_date_string\nbirl to_date_string","url":"birl.html#to_date_string"},{"doc":"birl","title":"to_erlang_datetime","content":"pub fn to_erlang_datetime(\n  value: Time,\n) -&gt; #(#(Int, Int, Int), #(Int, Int, Int))\n calculates erlang datetime using the offset in the DateTime value\nSynonyms:\nbirl.to_erlang_datetime\nbirl to_erlang_datetime","url":"birl.html#to_erlang_datetime"},{"doc":"birl","title":"to_erlang_universal_datetime","content":"pub fn to_erlang_universal_datetime(\n  value: Time,\n) -&gt; #(#(Int, Int, Int), #(Int, Int, Int))\n calculates the universal erlang datetime regardless of the offset in the DateTime value\nSynonyms:\nbirl.to_erlang_universal_datetime\nbirl to_erlang_universal_datetime","url":"birl.html#to_erlang_universal_datetime"},{"doc":"birl","title":"to_http","content":"pub fn to_http(value: Time) -&gt; String\n see [here](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Date)\nSynonyms:\nbirl.to_http\nbirl to_http","url":"birl.html#to_http"},{"doc":"birl","title":"to_http_with_offset","content":"pub fn to_http_with_offset(value: Time) -&gt; String\n like `to_http` but assumes the offset in the DateTime value instead of `GMT`\nSynonyms:\nbirl.to_http_with_offset\nbirl to_http_with_offset","url":"birl.html#to_http_with_offset"},{"doc":"birl","title":"to_iso8601","content":"pub fn to_iso8601(value: Time) -&gt; String\n\nSynonyms:\nbirl.to_iso8601\nbirl to_iso8601","url":"birl.html#to_iso8601"},{"doc":"birl","title":"to_naive","content":"pub fn to_naive(value: Time) -&gt; String\n the naive format is the same as ISO8601 except that it does not contain the offset\nSynonyms:\nbirl.to_naive\nbirl to_naive","url":"birl.html#to_naive"},{"doc":"birl","title":"to_naive_date_string","content":"pub fn to_naive_date_string(value: Time) -&gt; String\n like `to_date_string` except it does not contain the offset\nSynonyms:\nbirl.to_naive_date_string\nbirl to_naive_date_string","url":"birl.html#to_naive_date_string"},{"doc":"birl","title":"to_naive_time_string","content":"pub fn to_naive_time_string(value: Time) -&gt; String\n like `to_time_string` except it does not contain the offset\nSynonyms:\nbirl.to_naive_time_string\nbirl to_naive_time_string","url":"birl.html#to_naive_time_string"},{"doc":"birl","title":"to_time_string","content":"pub fn to_time_string(value: Time) -&gt; String\n returns a string which is the time part of an ISO8601 string along with the offset\nSynonyms:\nbirl.to_time_string\nbirl to_time_string","url":"birl.html#to_time_string"},{"doc":"birl","title":"to_unix","content":"pub fn to_unix(value: Time) -&gt; Int\n unix timestamps are the number of seconds that have elapsed since 00:00:00 UTC on January 1st, 1970\nSynonyms:\nbirl.to_unix\nbirl to_unix","url":"birl.html#to_unix"},{"doc":"birl","title":"utc_now","content":"pub fn utc_now() -&gt; Time\n use this to get the current time in utc\nSynonyms:\nbirl.utc_now\nbirl utc_now","url":"birl.html#utc_now"},{"doc":"birl","title":"weekday","content":"pub fn weekday(value: Time) -&gt; Weekday\n\nSynonyms:\nbirl.weekday\nbirl weekday","url":"birl.html#weekday"},{"doc":"birl","title":"birl","content":"","url":"birl.html"},{"doc":"birl/interval","title":"Interval","content":"pub opaque type Interval\n\n\nSynonyms:\nbirl/interval.Interval\nbirl/interval Interval","url":"birl/interval.html#Interval"},{"doc":"birl/interval","title":"contains","content":"pub fn contains(a: Interval, b: Interval) -&gt; Bool\n\nSynonyms:\nbirl/interval.contains\nbirl/interval contains","url":"birl/interval.html#contains"},{"doc":"birl/interval","title":"from_start_and_duration","content":"pub fn from_start_and_duration(\n  start: Time,\n  duration: Duration,\n) -&gt; Result(Interval, Nil)\n\nSynonyms:\nbirl/interval.from_start_and_duration\nbirl/interval from_start_and_duration","url":"birl/interval.html#from_start_and_duration"},{"doc":"birl/interval","title":"from_start_and_end","content":"pub fn from_start_and_end(\n  start: Time,\n  end: Time,\n) -&gt; Result(Interval, Nil)\n\nSynonyms:\nbirl/interval.from_start_and_end\nbirl/interval from_start_and_end","url":"birl/interval.html#from_start_and_end"},{"doc":"birl/interval","title":"get_bounds","content":"pub fn get_bounds(interval: Interval) -&gt; #(Time, Time)\n\nSynonyms:\nbirl/interval.get_bounds\nbirl/interval get_bounds","url":"birl/interval.html#get_bounds"},{"doc":"birl/interval","title":"includes","content":"pub fn includes(interval: Interval, time: Time) -&gt; Bool\n\nSynonyms:\nbirl/interval.includes\nbirl/interval includes","url":"birl/interval.html#includes"},{"doc":"birl/interval","title":"intersection","content":"pub fn intersection(a: Interval, b: Interval) -&gt; Option(Interval)\n\nSynonyms:\nbirl/interval.intersection\nbirl/interval intersection","url":"birl/interval.html#intersection"},{"doc":"birl/interval","title":"scale_down","content":"pub fn scale_down(interval: Interval, factor: Int) -&gt; Interval\n\nSynonyms:\nbirl/interval.scale_down\nbirl/interval scale_down","url":"birl/interval.html#scale_down"},{"doc":"birl/interval","title":"scale_up","content":"pub fn scale_up(interval: Interval, factor: Int) -&gt; Interval\n\nSynonyms:\nbirl/interval.scale_up\nbirl/interval scale_up","url":"birl/interval.html#scale_up"},{"doc":"birl/interval","title":"shift","content":"pub fn shift(interval: Interval, duration: Duration) -&gt; Interval\n\nSynonyms:\nbirl/interval.shift\nbirl/interval shift","url":"birl/interval.html#shift"},{"doc":"birl/interval","title":"birl/interval","content":"","url":"birl/interval.html"}]);